Crate genetic_rs_common

Crate genetic_rs_common 

The crate containing the core traits and structs of genetic-rs.

Modules

builtinbuiltin
Built-in nextgen functions and traits to go with them.
prelude
Used to quickly import everything this crate has to offer. Simply add use genetic_rs::prelude::* to begin using this crate.
speciationspeciation
Common speciation code used for speciated eliminators and repopulators.

Structs

GeneticSim
This struct is the main entry point for the simulation. It handles the state and evolution of the genomes based on what eliminator and repopulator it receives.

Traits

Eliminator
Tests and eliminates the unfit from the simulation.
GenerateRandomgenrand
Helper trait used in the generation of random starting populations
GenerateRandomCollectiongenrand
Blanket trait used on collections that contain objects implementing GenerateRandom
GenerateRandomCollectionParallelgenrand and rayon
Rayon version of the GenerateRandomCollection trait
Repopulator
Refills the population of the simulation based on survivors.