The crate containing the core traits and structs of genetic-rs.
Modules
- builtin
builtin - Built-in nextgen functions and traits to go with them.
- prelude
- Used to quickly import everything this crate has to offer.
Simply add
use genetic_rs::prelude::*to begin using this crate. - speciation
speciation - Common speciation code used for speciated eliminators and repopulators.
Structs
- Genetic
Sim - This struct is the main entry point for the simulation. It handles the state and evolution of the genomes based on what eliminator and repopulator it receives.
Traits
- Eliminator
- Tests and eliminates the unfit from the simulation.
- Generate
Random genrand - Helper trait used in the generation of random starting populations
- Generate
Random Collection genrand - Blanket trait used on collections that contain objects implementing
GenerateRandom - Generate
Random Collection Parallel genrandandrayon - Rayon version of the
GenerateRandomCollectiontrait - Repopulator
- Refills the population of the simulation based on survivors.